##########################
LDAP Authentication Module
##########################

The *LDAP Authentication Module* allows users to be authenticated using an
`LDAP <https://en.wikipedia.org/wiki/Lightweight_Directory_Access_Protocol>`_
server.

.. toctree::
   :maxdepth: 2

   configuration
   releases
